@@ -1,7 +1,7 @@
 import datetime
 import decimal
 import uuid
-from typing import Any, Optional, TYPE_CHECKING
+from typing import Any, Optional, TYPE_CHECKING, Union, overload
 
 import pydantic
 import sqlalchemy
@@ -11,6 +11,11 @@ from ormar.fields import sqlalchemy_uuid
 from ormar.fields.base import BaseField  # noqa I101
 from ormar.fields.sqlalchemy_encrypted import EncryptBackends
 
+try:
+    from typing import Literal
+except ImportError:  # pragma: no cover
+    from typing_extensions import Literal  # type: ignore
+
 
 def is_field_nullable(
     nullable: Optional[bool],
@@ -426,52 +431,85 @@ class JSON(ModelFieldFactory, pydantic.Json):
         return sqlalchemy.JSON()
 
 
-class LargeBinary(ModelFieldFactory, bytes):
-    """
-    LargeBinary field factory that construct Field classes and populated their values.
-    """
+if TYPE_CHECKING:  # pragma: nocover # noqa: C901
 
-    _type = bytes
-    _sample = "bytes"
+    @overload
+    def LargeBinary(
+        max_length: int, *, represent_as_base64_str: Literal[True], **kwargs: Any
+    ) -> str:
+        ...
 
-    def __new__(  # type: ignore # noqa CFQ002
-        cls, *, max_length: int, represent_as_base64_str: bool = False, **kwargs: Any
-    ) -> BaseField:  # type: ignore
-        kwargs = {
-            **kwargs,
-            **{
-                k: v
-                for k, v in locals().items()
-                if k not in ["cls", "__class__", "kwargs"]
-            },
-        }
-        return super().__new__(cls, **kwargs)
+    @overload
+    def LargeBinary(
+        max_length: int, *, represent_as_base64_str: Literal[False], **kwargs: Any
+    ) -> bytes:
+        ...
 
-    @classmethod
-    def get_column_type(cls, **kwargs: Any) -> Any:
+    @overload
+    def LargeBinary(
+        max_length: int, represent_as_base64_str: Literal[False] = ..., **kwargs: Any
+    ) -> bytes:
+        ...
+
+    def LargeBinary(
+        max_length: int, represent_as_base64_str: bool = False, **kwargs: Any
+    ) -> Union[str, bytes]:
+        pass
+
+
+else:
+
+    class LargeBinary(ModelFieldFactory, bytes):
+        """
+        LargeBinary field factory that construct Field classes
+        and populated their values.
         """
-        Return proper type of db column for given field type.
-        Accepts required and optional parameters that each column type accepts.
 
-        :param kwargs: key, value pairs of sqlalchemy options
-        :type kwargs: Any
-        :return: initialized column with proper options
-        :rtype: sqlalchemy Column
-        """
-        return sqlalchemy.LargeBinary(length=kwargs.get("max_length"))
+        _type = bytes
+        _sample = "bytes"
 
-    @classmethod
-    def validate(cls, **kwargs: Any) -> None:
-        """
-        Used to validate if all required parameters on a given field type are set.
-        :param kwargs: all params passed during construction
-        :type kwargs: Any
-        """
-        max_length = kwargs.get("max_length", None)
-        if max_length <= 0:
-            raise ModelDefinitionError(
-                "Parameter max_length is required for field LargeBinary"
-            )
+        def __new__(  # type: ignore # noqa CFQ002
+            cls,
+            *,
+            max_length: int,
+            represent_as_base64_str: bool = False,
+            **kwargs: Any
+        ) -> BaseField:  # type: ignore
+            kwargs = {
+                **kwargs,
+                **{
+                    k: v
+                    for k, v in locals().items()
+                    if k not in ["cls", "__class__", "kwargs"]
+                },
+            }
+            return super().__new__(cls, **kwargs)
+
+        @classmethod
+        def get_column_type(cls, **kwargs: Any) -> Any:
+            """
+            Return proper type of db column for given field type.
+            Accepts required and optional parameters that each column type accepts.
+
+            :param kwargs: key, value pairs of sqlalchemy options
+            :type kwargs: Any
+            :return: initialized column with proper options
+            :rtype: sqlalchemy Column
+            """
+            return sqlalchemy.LargeBinary(length=kwargs.get("max_length"))
+
+        @classmethod
+        def validate(cls, **kwargs: Any) -> None:
+            """
+            Used to validate if all required parameters on a given field type are set.
+            :param kwargs: all params passed during construction
+            :type kwargs: Any
+            """
+            max_length = kwargs.get("max_length", None)
+            if max_length <= 0:
+                raise ModelDefinitionError(
+                    "Parameter max_length is required for field LargeBinary"
+                )
 
 
 class BigInteger(Integer, int):
